:tocdepth: 3

Planet API - Python Client
==========================

This library provides a command-line-interface (CLI) and Python library to make access to Planet's public API easy to use.

The command line interface is intended to be functional for many tasks but is just a thin layer on the lower level Python API.

Also see the `API Reference Docs <https://developers.planet.com/docs/apis/>`_ for more information.

.. toctree::
   :maxdepth: 3

   cli/index
   api/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
